@@ -4,7 +4,7 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000011';
+our $VERSION = '0.000012';
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
@@ -357,10 +357,10 @@ sub wait {
         }
     }
 
-    cluck "All children have completed, but we still appear to be pending!"
-        if $self->pending;
-
     $hub->cull;
+
+    cluck "All children have completed, but we still appear to be pending"
+        if $hub->is_local && keys %{$self->{+HUB}->ast_ids};
 }
 
 sub fork {
